==> zio-aws-securityhub_2.13-5.17.115.1-sources.jar: zio/aws/securityhub/model/AwsElasticsearchDomainElasticsearchClusterConfigDetails.scala <==
package zio.aws.securityhub.model
import zio.ZIO
import zio.aws.securityhub.model.primitives.{NonEmptyString, Integer}
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class AwsElasticsearchDomainElasticsearchClusterConfigDetails(
    dedicatedMasterCount: Option[Integer] = None,
    dedicatedMasterEnabled: Option[Boolean] = None,
    dedicatedMasterType: Option[NonEmptyString] = None,
    instanceCount: Option[Integer] = None,
    instanceType: Option[NonEmptyString] = None,
    zoneAwarenessConfig: Option[
      zio.aws.securityhub.model.AwsElasticsearchDomainElasticsearchClusterConfigZoneAwarenessConfigDetails
    ] = None,
    zoneAwarenessEnabled: Option[Boolean] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.securityhub.model.AwsElasticsearchDomainElasticsearchClusterConfigDetails = {
    import AwsElasticsearchDomainElasticsearchClusterConfigDetails.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.securityhub.model.AwsElasticsearchDomainElasticsearchClusterConfigDetails
      .builder()
      .optionallyWith(
        dedicatedMasterCount.map(value =>
          Integer.unwrap(value): java.lang.Integer
        )
      )(_.dedicatedMasterCount)
      .optionallyWith(
        dedicatedMasterEnabled.map(value => value: java.lang.Boolean)
      )(_.dedicatedMasterEnabled)
      .optionallyWith(
        dedicatedMasterType.map(value =>
          NonEmptyString.unwrap(value): java.lang.String
        )
      )(_.dedicatedMasterType)
      .optionallyWith(
        instanceCount.map(value => Integer.unwrap(value): java.lang.Integer)
      )(_.instanceCount)
      .optionallyWith(
        instanceType.map(value =>
          NonEmptyString.unwrap(value): java.lang.String
        )
      )(_.instanceType)
      .optionallyWith(zoneAwarenessConfig.map(value => value.buildAwsValue()))(
        _.zoneAwarenessConfig
      )
      .optionallyWith(
        zoneAwarenessEnabled.map(value => value: java.lang.Boolean)
      )(_.zoneAwarenessEnabled)
      .build()
  }
  def asReadOnly
      : zio.aws.securityhub.model.AwsElasticsearchDomainElasticsearchClusterConfigDetails.ReadOnly =
    zio.aws.securityhub.model.AwsElasticsearchDomainElasticsearchClusterConfigDetails
      .wrap(buildAwsValue())
}
object AwsElasticsearchDomainElasticsearchClusterConfigDetails {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.securityhub.model.AwsElasticsearchDomainElasticsearchClusterConfigDetails
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.securityhub.model.AwsElasticsearchDomainElasticsearchClusterConfigDetails =
      zio.aws.securityhub.model
        .AwsElasticsearchDomainElasticsearchClusterConfigDetails(
          dedicatedMasterCount.map(value => value),
          dedicatedMasterEnabled.map(value => value),
          dedicatedMasterType.map(value => value),
          instanceCount.map(value => value),
          instanceType.map(value => value),
          zoneAwarenessConfig.map(value => value.asEditable),
          zoneAwarenessEnabled.map(value => value)
        )
    def dedicatedMasterCount: Option[Integer]
    def dedicatedMasterEnabled: Option[Boolean]
    def dedicatedMasterType: Option[NonEmptyString]
    def instanceCount: Option[Integer]
    def instanceType: Option[NonEmptyString]
    def zoneAwarenessConfig: Option[
      zio.aws.securityhub.model.AwsElasticsearchDomainElasticsearchClusterConfigZoneAwarenessConfigDetails.ReadOnly
    ]
    def zoneAwarenessEnabled: Option[Boolean]
    def getDedicatedMasterCount: ZIO[Any, AwsError, Integer] =
      AwsError.unwrapOptionField("dedicatedMasterCount", dedicatedMasterCount)
    def getDedicatedMasterEnabled: ZIO[Any, AwsError, Boolean] = AwsError
      .unwrapOptionField("dedicatedMasterEnabled", dedicatedMasterEnabled)
    def getDedicatedMasterType: ZIO[Any, AwsError, NonEmptyString] =
      AwsError.unwrapOptionField("dedicatedMasterType", dedicatedMasterType)
    def getInstanceCount: ZIO[Any, AwsError, Integer] =
      AwsError.unwrapOptionField("instanceCount", instanceCount)
    def getInstanceType: ZIO[Any, AwsError, NonEmptyString] =
      AwsError.unwrapOptionField("instanceType", instanceType)
    def getZoneAwarenessConfig: ZIO[
      Any,
      AwsError,
      zio.aws.securityhub.model.AwsElasticsearchDomainElasticsearchClusterConfigZoneAwarenessConfigDetails.ReadOnly
    ] = AwsError.unwrapOptionField("zoneAwarenessConfig", zoneAwarenessConfig)
    def getZoneAwarenessEnabled: ZIO[Any, AwsError, Boolean] =
      AwsError.unwrapOptionField("zoneAwarenessEnabled", zoneAwarenessEnabled)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.securityhub.model.AwsElasticsearchDomainElasticsearchClusterConfigDetails
  ) extends zio.aws.securityhub.model.AwsElasticsearchDomainElasticsearchClusterConfigDetails.ReadOnly {
    override val dedicatedMasterCount: Option[Integer] = scala
      .Option(impl.dedicatedMasterCount())
      .map(value => zio.aws.securityhub.model.primitives.Integer(value))
    override val dedicatedMasterEnabled: Option[Boolean] =
      scala.Option(impl.dedicatedMasterEnabled()).map(value => value: Boolean)
    override val dedicatedMasterType: Option[NonEmptyString] = scala
      .Option(impl.dedicatedMasterType())
      .map(value => zio.aws.securityhub.model.primitives.NonEmptyString(value))
    override val instanceCount: Option[Integer] = scala
      .Option(impl.instanceCount())
      .map(value => zio.aws.securityhub.model.primitives.Integer(value))
    override val instanceType: Option[NonEmptyString] = scala
      .Option(impl.instanceType())
      .map(value => zio.aws.securityhub.model.primitives.NonEmptyString(value))
    override val zoneAwarenessConfig: Option[
      zio.aws.securityhub.model.AwsElasticsearchDomainElasticsearchClusterConfigZoneAwarenessConfigDetails.ReadOnly
    ] = scala
      .Option(impl.zoneAwarenessConfig())
      .map(value =>
        zio.aws.securityhub.model.AwsElasticsearchDomainElasticsearchClusterConfigZoneAwarenessConfigDetails
          .wrap(value)
      )
    override val zoneAwarenessEnabled: Option[Boolean] =
      scala.Option(impl.zoneAwarenessEnabled()).map(value => value: Boolean)
  }
  def wrap(
      impl: software.amazon.awssdk.services.securityhub.model.AwsElasticsearchDomainElasticsearchClusterConfigDetails
  ): zio.aws.securityhub.model.AwsElasticsearchDomainElasticsearchClusterConfigDetails.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-securityhub_2.13-5.17.148.1-sources.jar: zio/aws/securityhub/model/AwsElasticsearchDomainElasticsearchClusterConfigDetails.scala <==
package zio.aws.securityhub.model
import zio.ZIO
import zio.aws.securityhub.model.primitives.{NonEmptyString, Integer}
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class AwsElasticsearchDomainElasticsearchClusterConfigDetails(
    dedicatedMasterCount: Option[Integer] = None,
    dedicatedMasterEnabled: Option[Boolean] = None,
    dedicatedMasterType: Option[NonEmptyString] = None,
    instanceCount: Option[Integer] = None,
    instanceType: Option[NonEmptyString] = None,
    zoneAwarenessConfig: Option[
      zio.aws.securityhub.model.AwsElasticsearchDomainElasticsearchClusterConfigZoneAwarenessConfigDetails
    ] = None,
    zoneAwarenessEnabled: Option[Boolean] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.securityhub.model.AwsElasticsearchDomainElasticsearchClusterConfigDetails = {
    import AwsElasticsearchDomainElasticsearchClusterConfigDetails.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.securityhub.model.AwsElasticsearchDomainElasticsearchClusterConfigDetails
      .builder()
      .optionallyWith(
        dedicatedMasterCount.map(value => value: java.lang.Integer)
      )(_.dedicatedMasterCount)
      .optionallyWith(
        dedicatedMasterEnabled.map(value => value: java.lang.Boolean)
      )(_.dedicatedMasterEnabled)
      .optionallyWith(
        dedicatedMasterType.map(value =>
          NonEmptyString.unwrap(value): java.lang.String
        )
      )(_.dedicatedMasterType)
      .optionallyWith(instanceCount.map(value => value: java.lang.Integer))(
        _.instanceCount
      )
      .optionallyWith(
        instanceType.map(value =>
          NonEmptyString.unwrap(value): java.lang.String
        )
      )(_.instanceType)
      .optionallyWith(zoneAwarenessConfig.map(value => value.buildAwsValue()))(
        _.zoneAwarenessConfig
      )
      .optionallyWith(
        zoneAwarenessEnabled.map(value => value: java.lang.Boolean)
      )(_.zoneAwarenessEnabled)
      .build()
  }
  def asReadOnly
      : zio.aws.securityhub.model.AwsElasticsearchDomainElasticsearchClusterConfigDetails.ReadOnly =
    zio.aws.securityhub.model.AwsElasticsearchDomainElasticsearchClusterConfigDetails
      .wrap(buildAwsValue())
}
object AwsElasticsearchDomainElasticsearchClusterConfigDetails {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.securityhub.model.AwsElasticsearchDomainElasticsearchClusterConfigDetails
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.securityhub.model.AwsElasticsearchDomainElasticsearchClusterConfigDetails =
      zio.aws.securityhub.model
        .AwsElasticsearchDomainElasticsearchClusterConfigDetails(
          dedicatedMasterCount.map(value => value),
          dedicatedMasterEnabled.map(value => value),
          dedicatedMasterType.map(value => value),
          instanceCount.map(value => value),
          instanceType.map(value => value),
          zoneAwarenessConfig.map(value => value.asEditable),
          zoneAwarenessEnabled.map(value => value)
        )
    def dedicatedMasterCount: Option[Integer]
    def dedicatedMasterEnabled: Option[Boolean]
    def dedicatedMasterType: Option[NonEmptyString]
    def instanceCount: Option[Integer]
    def instanceType: Option[NonEmptyString]
    def zoneAwarenessConfig: Option[
      zio.aws.securityhub.model.AwsElasticsearchDomainElasticsearchClusterConfigZoneAwarenessConfigDetails.ReadOnly
    ]
    def zoneAwarenessEnabled: Option[Boolean]
    def getDedicatedMasterCount: ZIO[Any, AwsError, Integer] =
      AwsError.unwrapOptionField("dedicatedMasterCount", dedicatedMasterCount)
    def getDedicatedMasterEnabled: ZIO[Any, AwsError, Boolean] = AwsError
      .unwrapOptionField("dedicatedMasterEnabled", dedicatedMasterEnabled)
    def getDedicatedMasterType: ZIO[Any, AwsError, NonEmptyString] =
      AwsError.unwrapOptionField("dedicatedMasterType", dedicatedMasterType)
    def getInstanceCount: ZIO[Any, AwsError, Integer] =
      AwsError.unwrapOptionField("instanceCount", instanceCount)
    def getInstanceType: ZIO[Any, AwsError, NonEmptyString] =
      AwsError.unwrapOptionField("instanceType", instanceType)
    def getZoneAwarenessConfig: ZIO[
      Any,
      AwsError,
      zio.aws.securityhub.model.AwsElasticsearchDomainElasticsearchClusterConfigZoneAwarenessConfigDetails.ReadOnly
    ] = AwsError.unwrapOptionField("zoneAwarenessConfig", zoneAwarenessConfig)
    def getZoneAwarenessEnabled: ZIO[Any, AwsError, Boolean] =
      AwsError.unwrapOptionField("zoneAwarenessEnabled", zoneAwarenessEnabled)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.securityhub.model.AwsElasticsearchDomainElasticsearchClusterConfigDetails
  ) extends zio.aws.securityhub.model.AwsElasticsearchDomainElasticsearchClusterConfigDetails.ReadOnly {
    override val dedicatedMasterCount: Option[Integer] =
      scala.Option(impl.dedicatedMasterCount()).map(value => value: Integer)
    override val dedicatedMasterEnabled: Option[Boolean] =
      scala.Option(impl.dedicatedMasterEnabled()).map(value => value: Boolean)
    override val dedicatedMasterType: Option[NonEmptyString] = scala
      .Option(impl.dedicatedMasterType())
      .map(value => zio.aws.securityhub.model.primitives.NonEmptyString(value))
    override val instanceCount: Option[Integer] =
      scala.Option(impl.instanceCount()).map(value => value: Integer)
    override val instanceType: Option[NonEmptyString] = scala
      .Option(impl.instanceType())
      .map(value => zio.aws.securityhub.model.primitives.NonEmptyString(value))
    override val zoneAwarenessConfig: Option[
      zio.aws.securityhub.model.AwsElasticsearchDomainElasticsearchClusterConfigZoneAwarenessConfigDetails.ReadOnly
    ] = scala
      .Option(impl.zoneAwarenessConfig())
      .map(value =>
        zio.aws.securityhub.model.AwsElasticsearchDomainElasticsearchClusterConfigZoneAwarenessConfigDetails
          .wrap(value)
      )
    override val zoneAwarenessEnabled: Option[Boolean] =
      scala.Option(impl.zoneAwarenessEnabled()).map(value => value: Boolean)
  }
  def wrap(
      impl: software.amazon.awssdk.services.securityhub.model.AwsElasticsearchDomainElasticsearchClusterConfigDetails
  ): zio.aws.securityhub.model.AwsElasticsearchDomainElasticsearchClusterConfigDetails.ReadOnly =
    new Wrapper(impl)
}
